@@ -1303,7 +1303,7 @@ int InterruptRead(int reader_index, int timeout /* in ms */)
 	if (usbDevice[reader_index].multislot_extension != NULL)
 		return Multi_InterruptRead(reader_index, timeout);
 
-	DEBUG_PERIODIC2("before (%d)", reader_index);
+	DEBUG_PERIODIC3("before (%d), timeout: %d ms", reader_index, timeout);
 
 	transfer = libusb_alloc_transfer(0);
 	if (NULL == transfer)
